Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(555)

Unified Diff: content/browser/payments/payment_app_context_impl.h

Issue 2785523003: PaymentHandler: Rename PaymentAppManager to PaymentManager. (Closed)
Patch Set: PaymentHandler: Rename PaymentAppManager to PaymentManager. Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/payments/payment_app_context_impl.h
diff --git a/content/browser/payments/payment_app_context_impl.h b/content/browser/payments/payment_app_context_impl.h
index b09d8f1ae63b837e8b273c1a55fda60effa3e712..2b9aa8f8bf3168b53f3e7eaea8c4bb1b24e3ab94 100644
--- a/content/browser/payments/payment_app_context_impl.h
+++ b/content/browser/payments/payment_app_context_impl.h
@@ -17,7 +17,7 @@
namespace content {
class PaymentAppDatabase;
-class PaymentAppManager;
+class PaymentManager;
class ServiceWorkerContextWrapper;
// One instance of this exists per StoragePartition, and services multiple child
@@ -34,9 +34,9 @@ class ServiceWorkerContextWrapper;
// 1) Constructor
// 2) Init()
// 3) Can now call other public methods in this class in any order.
// - Can call CreatePaymentAppManager() on UI thread.
// - Can call GetAllManifests() on UI thread.
// - Can call PaymentAppManagerHadConnectionError() on IO thread.
// - Can call payment_app_database() on IO thread.
// 4) Shutdown()
// 5) Destructor
@@ -52,14 +52,14 @@ class CONTENT_EXPORT PaymentAppContextImpl
// Shutdown must be called before deleting this. Call on the UI thread.
void Shutdown();
// Create a PaymentAppManager that is owned by this. Call on the UI
// thread.
- void CreatePaymentAppManager(
- mojo::InterfaceRequest<payments::mojom::PaymentAppManager> request);
+ void CreatePaymentManager(
+ mojo::InterfaceRequest<payments::mojom::PaymentManager> request);
- // Called by PaymentAppManager objects so that they can
+ // Called by PaymentManager objects so that they can
// be deleted. Call on the IO thread.
- void PaymentAppManagerHadConnectionError(PaymentAppManager* service);
+ void PaymentManagerHadConnectionError(PaymentManager* service);
// Should be accessed only on the IO thread.
PaymentAppDatabase* payment_app_database() const;
@@ -72,8 +72,8 @@ class CONTENT_EXPORT PaymentAppContextImpl
void CreatePaymentAppDatabaseOnIO(
scoped_refptr<ServiceWorkerContextWrapper> service_worker_context);
- void CreatePaymentAppManagerOnIO(
- mojo::InterfaceRequest<payments::mojom::PaymentAppManager> request);
+ void CreatePaymentManagerOnIO(
+ mojo::InterfaceRequest<payments::mojom::PaymentManager> request);
void ShutdownOnIO();
void DidShutdown();
@@ -81,11 +81,10 @@ class CONTENT_EXPORT PaymentAppContextImpl
// Only accessed on the IO thread.
std::unique_ptr<PaymentAppDatabase> payment_app_database_;
- // The PaymentAppManagers are owned by this. They're either deleted during
+ // The PaymentManagers are owned by this. They're either deleted during
// ShutdownOnIO or when the channel is closed via
- // PaymentAppManagerHadConnectionError. Only accessed on the IO thread.
- std::map<PaymentAppManager*, std::unique_ptr<PaymentAppManager>>
- payment_app_managers_;
+ // PaymentManagerHadConnectionError. Only accessed on the IO thread.
+ std::map<PaymentManager*, std::unique_ptr<PaymentManager>> payment_managers_;
// Only accessed on the UI thread.
bool is_shutdown_;
« no previous file with comments | « content/browser/payments/payment_app_content_unittest_base.cc ('k') | content/browser/payments/payment_app_context_impl.cc » ('j') | no next file with comments »
@@ -34,9 +34,9 @@ class ServiceWorkerContextWrapper;
// 2) Init()
// 3) Can now call other public methods in this class in any order.
-// - Can call CreatePaymentAppManager() on UI thread.
+// - Can call CreatePaymentManager() on UI thread.
// - Can call GetAllManifests() on UI thread.
@@ -34,9 +34,9 @@ class ServiceWorkerContextWrapper;
// - Can call GetAllManifests() on UI thread.
-// - Can call PaymentAppManagerHadConnectionError() on IO thread.
+// - Can call PaymentManagerHadConnectionError() on IO thread.
// - Can call payment_app_database() on IO thread.
// 4) Shutdown()
@@ -52,14 +52,14 @@ class CONTENT_EXPORT PaymentAppContextImpl
// Shutdown must be called before deleting this. Call on the UI thread.
void Shutdown();
- // Create a PaymentAppManager that is owned by this. Call on the UI
+ // Create a PaymentManager that is owned by this. Call on the UI
// thread.

Powered by Google App Engine
This is Rietveld 408576698